update_entities_page — Camelot documentation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- wizard »
- pages »

# update_entities_page

Created on Jan 18, 2010

@author: tw55413

class `camelot.view.wizard.pages.update_entities_page.` `UpdateEntitiesPage`(collection_getter, parent)

  A progress page that updates each entity in a collection, then flushes the entity, and informs all views that the entity has been updated. Subclass this page and implement update_entity to make this page do something.

  `update_entity`(entity)

    Implement this method to update the entities in the collection.

    Parameters: | entity – the entity that should be updated
    Returns: | None or a string that will be displayed in the progress

    screen.

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- wizard »
- pages »

Comments
blog comments powered by Disqus